/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#include <activemq/connector/openwire/commands/ConnectionControl.h>
#include <activemq/exceptions/NullPointerException.h>

using namespace std;
using namespace activemq;
using namespace activemq::exceptions;
using namespace activemq::connector;
using namespace activemq::connector::openwire;
using namespace activemq::connector::openwire::commands;

/*
 *
 *  Command and marshalling code for OpenWire format for ConnectionControl
 *
 *
 *  NOTE!: This file is autogenerated - do not modify!
 *         if you need to make a change, please see the Java Classes in the
 *         activemq-core module
 *
 */
////////////////////////////////////////////////////////////////////////////////
ConnectionControl::ConnectionControl()
{
    this->close = false;
    this->exit = false;
    this->faultTolerant = false;
    this->resume = false;
    this->suspend = false;
}

////////////////////////////////////////////////////////////////////////////////
ConnectionControl::~ConnectionControl()
{
}

////////////////////////////////////////////////////////////////////////////////
DataStructure* ConnectionControl::cloneDataStructure() const {
    ConnectionControl* connectionControl = new ConnectionControl();

    // Copy the data from the base class or classes
    connectionControl->copyDataStructure( this );

    return connectionControl;
}

////////////////////////////////////////////////////////////////////////////////
void ConnectionControl::copyDataStructure( const DataStructure* src ) {

    // Copy the data of the base class or classes
    BaseCommand::copyDataStructure( src );

    const ConnectionControl* srcPtr = dynamic_cast<const ConnectionControl*>( src );

    if( srcPtr == NULL || src == NULL ) {
    
        throw exceptions::NullPointerException(
            __FILE__, __LINE__,
            "ConnectionControl::copyDataStructure - src is NULL or invalid" );
    }
    this->setClose( srcPtr->isClose() );
    this->setExit( srcPtr->isExit() );
    this->setFaultTolerant( srcPtr->isFaultTolerant() );
    this->setResume( srcPtr->isResume() );
    this->setSuspend( srcPtr->isSuspend() );
}

////////////////////////////////////////////////////////////////////////////////
unsigned char ConnectionControl::getDataStructureType() const {
    return ConnectionControl::ID_CONNECTIONCONTROL; 
}

////////////////////////////////////////////////////////////////////////////////
const bool ConnectionControl::isClose() const {
    return close;
}

////////////////////////////////////////////////////////////////////////////////
bool ConnectionControl::isClose() {
    return close;
}

////////////////////////////////////////////////////////////////////////////////
void ConnectionControl::setClose(bool close ) {
    this->close = close;
}

////////////////////////////////////////////////////////////////////////////////
const bool ConnectionControl::isExit() const {
    return exit;
}

////////////////////////////////////////////////////////////////////////////////
bool ConnectionControl::isExit() {
    return exit;
}

////////////////////////////////////////////////////////////////////////////////
void ConnectionControl::setExit(bool exit ) {
    this->exit = exit;
}

////////////////////////////////////////////////////////////////////////////////
const bool ConnectionControl::isFaultTolerant() const {
    return faultTolerant;
}

////////////////////////////////////////////////////////////////////////////////
bool ConnectionControl::isFaultTolerant() {
    return faultTolerant;
}

////////////////////////////////////////////////////////////////////////////////
void ConnectionControl::setFaultTolerant(bool faultTolerant ) {
    this->faultTolerant = faultTolerant;
}

////////////////////////////////////////////////////////////////////////////////
const bool ConnectionControl::isResume() const {
    return resume;
}

////////////////////////////////////////////////////////////////////////////////
bool ConnectionControl::isResume() {
    return resume;
}

////////////////////////////////////////////////////////////////////////////////
void ConnectionControl::setResume(bool resume ) {
    this->resume = resume;
}

////////////////////////////////////////////////////////////////////////////////
const bool ConnectionControl::isSuspend() const {
    return suspend;
}

////////////////////////////////////////////////////////////////////////////////
bool ConnectionControl::isSuspend() {
    return suspend;
}

////////////////////////////////////////////////////////////////////////////////
void ConnectionControl::setSuspend(bool suspend ) {
    this->suspend = suspend;
}

