/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#include <activemq/connector/openwire/commands/MessageDispatch.h>
#include <activemq/exceptions/NullPointerException.h>

using namespace std;
using namespace activemq;
using namespace activemq::exceptions;
using namespace activemq::connector;
using namespace activemq::connector::openwire;
using namespace activemq::connector::openwire::commands;

/*
 *
 *  Command and marshalling code for OpenWire format for MessageDispatch
 *
 *
 *  NOTE!: This file is autogenerated - do not modify!
 *         if you need to make a change, please see the Java Classes in the
 *         activemq-core module
 *
 */
////////////////////////////////////////////////////////////////////////////////
MessageDispatch::MessageDispatch()
{
    this->consumerId = NULL;
    this->destination = NULL;
    this->message = NULL;
    this->redeliveryCounter = 0;
}

////////////////////////////////////////////////////////////////////////////////
MessageDispatch::~MessageDispatch()
{
    delete this->consumerId;
    delete this->destination;
    delete this->message;
}

////////////////////////////////////////////////////////////////////////////////
DataStructure* MessageDispatch::cloneDataStructure() const {
    MessageDispatch* messageDispatch = new MessageDispatch();

    // Copy the data from the base class or classes
    messageDispatch->copyDataStructure( this );

    return messageDispatch;
}

////////////////////////////////////////////////////////////////////////////////
void MessageDispatch::copyDataStructure( const DataStructure* src ) {

    // Copy the data of the base class or classes
    BaseCommand::copyDataStructure( src );

    const MessageDispatch* srcPtr = dynamic_cast<const MessageDispatch*>( src );

    if( srcPtr == NULL || src == NULL ) {
    
        throw exceptions::NullPointerException(
            __FILE__, __LINE__,
            "MessageDispatch::copyDataStructure - src is NULL or invalid" );
    }
    this->setConsumerId( 
        dynamic_cast<ConsumerId*>( 
            srcPtr->getConsumerId()->cloneDataStructure() ) );
    this->setDestination( 
        dynamic_cast<ActiveMQDestination*>( 
            srcPtr->getDestination()->cloneDataStructure() ) );
    this->setMessage( 
        dynamic_cast<Message*>( 
            srcPtr->getMessage()->cloneDataStructure() ) );
    this->setRedeliveryCounter( srcPtr->getRedeliveryCounter() );
}

////////////////////////////////////////////////////////////////////////////////
unsigned char MessageDispatch::getDataStructureType() const {
    return MessageDispatch::ID_MESSAGEDISPATCH; 
}

////////////////////////////////////////////////////////////////////////////////
const ConsumerId* MessageDispatch::getConsumerId() const {
    return consumerId;
}

////////////////////////////////////////////////////////////////////////////////
ConsumerId* MessageDispatch::getConsumerId() {
    return consumerId;
}

////////////////////////////////////////////////////////////////////////////////
void MessageDispatch::setConsumerId(ConsumerId* consumerId ) {
    this->consumerId = consumerId;
}

////////////////////////////////////////////////////////////////////////////////
const ActiveMQDestination* MessageDispatch::getDestination() const {
    return destination;
}

////////////////////////////////////////////////////////////////////////////////
ActiveMQDestination* MessageDispatch::getDestination() {
    return destination;
}

////////////////////////////////////////////////////////////////////////////////
void MessageDispatch::setDestination(ActiveMQDestination* destination ) {
    this->destination = destination;
}

////////////////////////////////////////////////////////////////////////////////
const Message* MessageDispatch::getMessage() const {
    return message;
}

////////////////////////////////////////////////////////////////////////////////
Message* MessageDispatch::getMessage() {
    return message;
}

////////////////////////////////////////////////////////////////////////////////
void MessageDispatch::setMessage(Message* message ) {
    this->message = message;
}

////////////////////////////////////////////////////////////////////////////////
const int MessageDispatch::getRedeliveryCounter() const {
    return redeliveryCounter;
}

////////////////////////////////////////////////////////////////////////////////
int MessageDispatch::getRedeliveryCounter() {
    return redeliveryCounter;
}

////////////////////////////////////////////////////////////////////////////////
void MessageDispatch::setRedeliveryCounter(int redeliveryCounter ) {
    this->redeliveryCounter = redeliveryCounter;
}

